@@ -1,13 +1,12 @@
 package Pithub::Issues::Comments;
 BEGIN {
-  $Pithub::Issues::Comments::VERSION = '0.01004';
+  $Pithub::Issues::Comments::VERSION = '0.01005';
 }
 
 # ABSTRACT: Github v3 Issue Comments API
 
-use Moose;
+use Moo;
 use Carp qw(croak);
-use namespace::autoclean;
 extends 'Pithub::Base';
 
 
@@ -72,8 +71,6 @@ sub update {
     );
 }
 
-__PACKAGE__->meta->make_immutable;
-
 1;
 
 __END__
@@ -85,7 +82,7 @@ Pithub::Issues::Comments - Github v3 Issue Comments API
 
 =head1 VERSION
 
-version 0.01004
+version 0.01005
 
 =head1 METHODS
 
