@@ -1,18 +1,28 @@
 package Pithub::Users;
 BEGIN {
-  $Pithub::Users::VERSION = '0.01004';
+  $Pithub::Users::VERSION = '0.01005';
 }
 
 # ABSTRACT: Github v3 Users API
 
-use Moose;
+use Moo;
 use Carp qw(croak);
-use namespace::autoclean;
+use Pithub::Users::Emails;
+use Pithub::Users::Followers;
+use Pithub::Users::Keys;
 extends 'Pithub::Base';
-with 'MooseX::Role::BuildInstanceOf' => { target => '::Emails' };
-with 'MooseX::Role::BuildInstanceOf' => { target => '::Followers' };
-with 'MooseX::Role::BuildInstanceOf' => { target => '::Keys' };
-around qr{^merge_.*?_args$}          => \&Pithub::Base::_merge_args;
+
+sub emails {
+    return shift->_create_instance('Pithub::Users::Emails');
+}
+
+sub followers {
+    return shift->_create_instance('Pithub::Users::Followers');
+}
+
+sub keys {
+    return shift->_create_instance('Pithub::Users::Keys');
+}
 
 
 sub get {
@@ -42,8 +52,6 @@ sub update {
     );
 }
 
-__PACKAGE__->meta->make_immutable;
-
 1;
 
 __END__
@@ -55,7 +63,7 @@ Pithub::Users - Github v3 Users API
 
 =head1 VERSION
 
-version 0.01004
+version 0.01005
 
 =head1 METHODS
 
